@@ -6,22 +6,17 @@ import SoftLayer
 from SoftLayer.CLI import environment
 
 
-@click.command()
+@click.command(cls=SoftLayer.CLI.command.SLCommand, )
 @click.argument('volume-id')
 @click.option('--replicant-id', help="ID of the replicant volume")
-@click.option('--immediate',
-              is_flag=True,
-              default=False,
-              help="Failover to replicant immediately.")
 @environment.pass_env
-def cli(env, volume_id, replicant_id, immediate):
+def cli(env, volume_id, replicant_id):
     """Failover a block volume to the given replicant volume."""
     block_storage_manager = SoftLayer.BlockStorageManager(env.client)
 
     success = block_storage_manager.failover_to_replicant(
         volume_id,
-        replicant_id,
-        immediate
+        replicant_id
     )
 
     if success:
