@@ -6,15 +6,18 @@
     :license: MIT, see LICENSE for more details.
 """
 import importlib
+from json.decoder import JSONDecodeError
 
 import click
 import pkg_resources
+from rich.console import Console
+from rich.syntax import Syntax
 
 import SoftLayer
 from SoftLayer.CLI import formatting
 from SoftLayer.CLI import routes
 
-# pylint: disable=too-many-instance-attributes, invalid-name, no-self-use
+# pylint: disable=too-many-instance-attributes, invalid-name
 
 # Calling pkg_resources.iter_entry_points shows a false-positive
 # pylint: disable=no-member
@@ -32,19 +35,38 @@ class Environment(object):
         self.vars = {}
 
         self.client = None
+        self.console = Console()
+        self.err_console = Console(stderr=True)
         self.format = 'table'
         self.skip_confirmations = False
         self.config_file = None
 
         self._modules_loaded = False
 
-    def out(self, output, newline=True):
+    def out(self, output):
         """Outputs a string to the console (stdout)."""
-        click.echo(output, nl=newline)
+        if self.format == 'json':
+            try:
+                self.console.print_json(output)
+            # Tried to print not-json, so just print it out normally...
+            except JSONDecodeError:
+                click.echo(output)
+        elif self.format == 'jsonraw':
+            #  Using Rich here is problematic because in the unit tests it thinks the terminal is 80 characters wide
+            #  and only prints out that many characters.
+            click.echo(output)
+        else:
+            # If we want to print a list of tables, Rich doens't handle that well.
+            if isinstance(output, list):
+                for line in output:
+                    self.console.print(line, overflow='ignore')
+            else:
+                self.console.print(output,  overflow='ignore')
 
     def err(self, output, newline=True):
         """Outputs an error string to the console (stderr)."""
-        click.echo(output, nl=newline, err=True)
+
+        self.err_console.print(output, new_line_start=newline)
 
     def fmt(self, output, fmt=None):
         """Format output based on current the environment format."""
@@ -52,14 +74,22 @@ class Environment(object):
             fmt = self.format
         return formatting.format_output(output, fmt)
 
-    def fout(self, output, newline=True):
+    def format_output_is_json(self):
+        """Return True if format output is json or jsonraw"""
+        return 'json' in self.format
+
+    def fout(self, output):
         """Format the input and output to the console (stdout)."""
         if output is not None:
             try:
-                self.out(self.fmt(output), newline=newline)
+                self.out(self.fmt(output))
             except UnicodeEncodeError:
                 # If we hit an undecodeable entry, just try outputting as json.
-                self.out(self.fmt(output, 'json'), newline=newline)
+                self.out(self.fmt(output, 'json'))
+
+    def python_output(self, output):
+        """Prints out python code"""
+        self.console.print(Syntax(output, "python"))
 
     def input(self, prompt, default=None, show_default=True):
         """Provide a command prompt."""
@@ -67,7 +97,23 @@ class Environment(object):
 
     def getpass(self, prompt, default=None):
         """Provide a password prompt."""
-        return click.prompt(prompt, hide_input=True, default=default)
+        password = click.prompt(prompt, hide_input=True, default=default)
+
+        # https://github.com/softlayer/softlayer-python/issues/1436
+        # click.prompt uses python's getpass() in the background
+        # https://github.com/python/cpython/blob/3.9/Lib/getpass.py#L97
+        # In windows, shift+insert actually inputs the below 2 characters
+        # If we detect those 2 characters, need to manually read from the clipbaord instead
+        # https://stackoverflow.com/questions/101128/how-do-i-read-text-from-the-clipboard
+        if password == 'àR':
+            # tkinter is a built in python gui, but it has clipboard reading functions.
+            # pylint: disable=import-outside-toplevel
+            from tkinter import Tk
+            tk_manager = Tk()
+            password = tk_manager.clipboard_get()
+            # keep the window from showing
+            tk_manager.withdraw()
+        return password
 
     # Command loading methods
     def list_commands(self, *path):
