@@ -15,6 +15,7 @@ ALL_ROUTES = [
     ('account:invoice-detail', 'SoftLayer.CLI.account.invoice_detail:cli'),
     ('account:invoices', 'SoftLayer.CLI.account.invoices:cli'),
     ('account:events', 'SoftLayer.CLI.account.events:cli'),
+    ('account:bandwidth-pools-detail', 'SoftLayer.CLI.account.bandwidth_pools_detail:cli'),
     ('account:event-detail', 'SoftLayer.CLI.account.event_detail:cli'),
     ('account:licenses', 'SoftLayer.CLI.account.licenses:cli'),
     ('account:summary', 'SoftLayer.CLI.account.summary:cli'),
@@ -51,6 +52,7 @@ ALL_ROUTES = [
     ('virtual:capacity', 'SoftLayer.CLI.virt.capacity:cli'),
     ('virtual:placementgroup', 'SoftLayer.CLI.virt.placementgroup:cli'),
     ('virtual:migrate', 'SoftLayer.CLI.virt.migrate:cli'),
+    ('virtual:monitoring', 'SoftLayer.CLI.virt.monitoring:cli'),
 
     ('dedicatedhost', 'SoftLayer.CLI.dedicatedhost'),
     ('dedicatedhost:list', 'SoftLayer.CLI.dedicatedhost.list:cli'),
@@ -91,6 +93,7 @@ ALL_ROUTES = [
     ('block:access-list', 'SoftLayer.CLI.block.access.list:cli'),
     ('block:access-revoke', 'SoftLayer.CLI.block.access.revoke:cli'),
     ('block:access-password', 'SoftLayer.CLI.block.access.password:cli'),
+    ('block:duplicate-convert-status', 'SoftLayer.CLI.block.duplicate_convert_status:cli'),
     ('block:subnets-list', 'SoftLayer.CLI.block.subnets.list:cli'),
     ('block:subnets-assign', 'SoftLayer.CLI.block.subnets.assign:cli'),
     ('block:subnets-remove', 'SoftLayer.CLI.block.subnets.remove:cli'),
@@ -123,6 +126,9 @@ ALL_ROUTES = [
     ('block:volume-refresh', 'SoftLayer.CLI.block.refresh:cli'),
     ('block:volume-convert', 'SoftLayer.CLI.block.convert:cli'),
     ('block:volume-set-note', 'SoftLayer.CLI.block.set_note:cli'),
+    ('block:object-list', 'SoftLayer.CLI.block.object_list:cli'),
+    ('block:object-storage-detail', 'SoftLayer.CLI.block.object_storage_detail:cli'),
+    ('block:object-storage-permission', 'SoftLayer.CLI.block.object_storage_permission:cli'),
 
     ('email', 'SoftLayer.CLI.email'),
     ('email:list', 'SoftLayer.CLI.email.list:cli'),
@@ -140,6 +146,7 @@ ALL_ROUTES = [
     ('file:access-authorize', 'SoftLayer.CLI.file.access.authorize:cli'),
     ('file:access-list', 'SoftLayer.CLI.file.access.list:cli'),
     ('file:access-revoke', 'SoftLayer.CLI.file.access.revoke:cli'),
+    ('file:duplicate-convert-status', 'SoftLayer.CLI.file.duplicate_convert_status:cli'),
     ('file:replica-failback', 'SoftLayer.CLI.file.replication.failback:cli'),
     ('file:replica-failover', 'SoftLayer.CLI.file.replication.failover:cli'),
     ('file:disaster-recovery-failover', 'SoftLayer.CLI.file.replication.disaster_recovery_failover:cli'),
@@ -175,6 +182,7 @@ ALL_ROUTES = [
     ('firewall:detail', 'SoftLayer.CLI.firewall.detail:cli'),
     ('firewall:edit', 'SoftLayer.CLI.firewall.edit:cli'),
     ('firewall:list', 'SoftLayer.CLI.firewall.list:cli'),
+    ('firewall:monitoring', 'SoftLayer.CLI.firewall.monitoring:cli'),
 
     ('globalip', 'SoftLayer.CLI.globalip'),
     ('globalip:assign', 'SoftLayer.CLI.globalip.assign:cli'),
@@ -279,6 +287,7 @@ ALL_ROUTES = [
     ('hardware:storage', 'SoftLayer.CLI.hardware.storage:cli'),
     ('hardware:upgrade', 'SoftLayer.CLI.hardware.upgrade:cli'),
     ('hardware:sensor', 'SoftLayer.CLI.hardware.sensor:cli'),
+    ('hardware:monitoring', 'SoftLayer.CLI.hardware.monitoring:cli'),
 
     ('securitygroup', 'SoftLayer.CLI.securitygroup'),
     ('securitygroup:list', 'SoftLayer.CLI.securitygroup.list:cli'),
@@ -320,6 +329,7 @@ ALL_ROUTES = [
     ('subnet:list', 'SoftLayer.CLI.subnet.list:cli'),
     ('subnet:lookup', 'SoftLayer.CLI.subnet.lookup:cli'),
     ('subnet:edit-ip', 'SoftLayer.CLI.subnet.edit_ip:cli'),
+    ('subnet:route', 'SoftLayer.CLI.subnet.route:cli'),
 
     ('tags', 'SoftLayer.CLI.tags'),
     ('tags:cleanup', 'SoftLayer.CLI.tags.cleanup:cli'),
@@ -365,14 +375,17 @@ ALL_ROUTES = [
 
     ('report', 'SoftLayer.CLI.report'),
     ('report:bandwidth', 'SoftLayer.CLI.report.bandwidth:cli'),
+    ('report:datacenter-closures', 'SoftLayer.CLI.report.dc_closures:cli'),
 
     ('autoscale', 'SoftLayer.CLI.autoscale'),
     ('autoscale:list', 'SoftLayer.CLI.autoscale.list:cli'),
+    ('autoscale:create', 'SoftLayer.CLI.autoscale.create:cli'),
     ('autoscale:detail', 'SoftLayer.CLI.autoscale.detail:cli'),
     ('autoscale:scale', 'SoftLayer.CLI.autoscale.scale:cli'),
     ('autoscale:logs', 'SoftLayer.CLI.autoscale.logs:cli'),
     ('autoscale:tag', 'SoftLayer.CLI.autoscale.tag:cli'),
-    ('autoscale:edit', 'SoftLayer.CLI.autoscale.edit:cli')
+    ('autoscale:edit', 'SoftLayer.CLI.autoscale.edit:cli'),
+    ('autoscale:delete', 'SoftLayer.CLI.autoscale.delete:cli'),
 ]
 
 ALL_ALIASES = {
