@@ -118,7 +118,7 @@ def _parse_create_args(client, args):
     if args.get('userdata'):
         data['userdata'] = args['userdata']
     elif args.get('userfile'):
-        with open(args['userfile'], 'r') as userfile:
+        with open(args['userfile'], 'r', encoding="utf-8") as userfile:
             data['userdata'] = userfile.read()
 
     # Get the SSH keys
@@ -151,7 +151,7 @@ def _parse_create_args(client, args):
     return data
 
 
-@click.command(epilog="See 'slcli vs create-options' for valid options")
+@click.command(cls=SoftLayer.CLI.command.SLCommand, epilog="See 'slcli vs create-options' for valid options")
 @click.option('--hostname', '-H', required=True, prompt=True, help="Host portion of the FQDN")
 @click.option('--domain', '-D', required=True, prompt=True, help="Domain portion of the FQDN")
 @click.option('--cpu', '-c', type=click.INT, help="Number of CPU cores (not available with flavors)")
@@ -177,7 +177,7 @@ def _parse_create_args(client, args):
               help="Forces the VS to only have access the private network")
 @click.option('--like', is_eager=True, callback=_update_with_like_args,
               help="Use the configuration from an existing VS")
-@click.option('--network', '-n', help="Network port speed in Mbps")
+@click.option('--network', '-n', help="Network port speed in Mbps", type=click.INT)
 @helpers.multi_option('--tag', '-g', help="Tags to add to the instance")
 @click.option('--template', '-t', is_eager=True,
               callback=template.TemplateCallback(list_args=['disk', 'key', 'tag']),
@@ -218,8 +218,16 @@ def cli(env, **args):
     create_args = _parse_create_args(env.client, args)
     test = args.get('test', False)
     do_create = not (args.get('export') or test)
+    network = SoftLayer.NetworkManager(env.client)
+
+    pods = network.get_closed_pods()
+    closure = []
 
     if do_create:
+        for pod in pods:
+            if args.get('datacenter') in str(pod['name']):
+                closure.append(pod['name'])
+        click.secho(click.style('Warning: Closed soon: %s' % (', '.join(closure)), fg='yellow'))
         if not (env.skip_confirmations or formatting.confirm(
                 "This action will incur charges on your account. Continue?")):
             raise exceptions.CLIAbort('Aborting virtual server order.')
