@@ -501,6 +501,7 @@ getNetworkVlans = [{
     'totalPrimaryIpAddressCount': 1,
     'subnetCount': 0,
     'subnets': [],
+    'tagReferences': [],
     'firewallInterfaces': [
         {
             'id': 1,
@@ -538,6 +539,7 @@ getNetworkVlans = [{
     'firewallInterfaces': [],
 
     'subnetCount': 0,
+    'tagReferences': [],
     'subnets': [],
 }, {
     'id': 3,
@@ -561,6 +563,7 @@ getNetworkVlans = [{
     'totalPrimaryIpAddressCount': 3,
     'subnetCount': 0,
     'subnets': [],
+    'tagReferences': [],
     'virtualGuestCount': 1,
     'virtualGuests': [{'id': 3}]
 }]
@@ -644,8 +647,36 @@ getBalance = 40
 
 getNextInvoiceTotalAmount = 2
 
-getHubNetworkStorage = [{'id': 12345, 'username': 'SLOS12345-1', 'serviceResource': {'name': 'Cleversafe - US Region'}},
-                        {'id': 12346, 'username': 'SLOS12345-2', 'vendorName': 'Swift'}]
+getHubNetworkStorage = [
+    {
+        "id": 12345,
+        "username": "SLOS12345-1",
+        "billingItem": {
+            "createDate": "2020-10-08T11:45:17-06:00"
+        },
+        "serviceResource": {
+            "name": "Cleversafe - US Region"
+        },
+        "storageType": {
+            "description": "Object Storage Standard Account",
+            "id": 24,
+            "keyName": "OBJECT_STORAGE_STANDARD"
+        }
+    },
+    {
+        "id": 12346,
+        "username": "SLOS12345-2",
+        "vendorName": "Swift",
+        "billingItem": {
+            "createDate": "2020-10-08T11:45:17-06:00"
+        },
+        "storageType": {
+            "description": "Object Storage Standard Account",
+            "id": 24,
+            "keyName": "OBJECT_STORAGE_STANDARD"
+        }
+    }
+]
 
 getIscsiNetworkStorage = [{
     'accountId': 1234,
@@ -1225,3 +1256,41 @@ getBandwidthAllotments = [{
     'projectedPublicBandwidthUsage': 9.88,
     'totalBandwidthAllocated': 3361
 }]
+
+getNetworkGateways = [{
+    'id': 615448,
+    'name': 'testFirewall-cgallo',
+    'networkSpace': 'BOTH',
+    'insideVlans': [],
+    'members': [
+        {
+            'id': 687820,
+            'hardware': {
+                'hostname': 'dft03.pod03.dal13'
+            }
+        }
+    ],
+    'networkFirewall': {
+        'id': 17438,
+        'datacenter': {
+            'name': 'dal13'
+        },
+        'firewallType': 'fortigate-security-appliance-10gb',
+        'rules': []
+    },
+    'privateIpAddress': {
+        'ipAddress': '10.37.115.70'
+    },
+    'publicIpAddress': {
+        'ipAddress': '67.228.206.245'
+    },
+    'publicVlan': {
+        'id': 3228726,
+        'primaryRouter': {
+            'hostname': 'fcr03a.dal13'
+        }
+    },
+    'status': {
+        'keyName': 'ACTIVE'
+    }
+}]
