@@ -1,15 +1,22 @@
 getObject = {
     'id': 1000,
     'globalIdentifier': '1a2b3c-1701',
-    'datacenter': {'id': 50, 'name': 'TEST00',
+    'datacenter': {'id': 50, 'name': 'TEST00', 'longName': 'test 00',
                    'description': 'Test Data Center'},
     'billingItem': {
         'id': 6327,
         'recurringFee': 1.54,
+        'package': {
+            'id': 911
+        },
         'nextInvoiceTotalRecurringAmount': 16.08,
         'children': [
             {'description': 'test', 'nextInvoiceTotalRecurringAmount': 1},
         ],
+        'nextInvoiceChildren': [
+            {'description': 'test', 'nextInvoiceTotalRecurringAmount': 1, 'categoryCode': 'disk1'},
+            {'description': 'test2', 'nextInvoiceTotalRecurringAmount': 2, 'categoryCode': 'disk3'}
+        ],
         'orderItem': {
             'order': {
                 'userRecord': {
@@ -67,7 +74,35 @@ getObject = {
             'friendlyName': 'Friendly Transaction Name',
             'id': 6660
         }
-    }
+    },
+    'networkMonitors': [
+        {
+            'hardwareId': 3123796,
+            'hostId': 3123796,
+            'id': 19016454,
+            'ipAddress': '169.53.167.199',
+            'queryTypeId': 1,
+            'responseActionId': 2,
+            'status': 'ON',
+            'waitCycles': 0,
+            'lastResult': {
+                'finishTime': '2022-03-10T08:31:40-06:00',
+                'responseStatus': 2,
+                'responseTime': 159.15,
+            },
+            'queryType': {
+                'description': 'Test ping to address',
+                'id': 1,
+                'monitorLevel': 0,
+                'name': 'SERVICE PING'
+            },
+            'responseAction': {
+                'actionDescription': 'Notify Users',
+                'id': 2,
+                'level': 0
+            }
+        }
+    ]
 }
 editObject = True
 setTags = True
@@ -262,3 +297,129 @@ getVirtualHost = {
         }
     }
 }
+
+getUpgradeItemPrices = [
+    {
+        "id": 21525,
+        "recurringFee": "0",
+        "categories": [
+            {
+                "categoryCode": "port_speed",
+                "id": 26,
+                "name": "Uplink Port Speeds",
+            }
+        ],
+        "item": {
+            "capacity": "10000",
+            "description": "10 Gbps Redundant Public & Private Network Uplinks",
+            "id": 4342,
+            "keyName": "10_GBPS_REDUNDANT_PUBLIC_PRIVATE_NETWORK_UPLINKS"
+        }
+    },
+    {
+        "hourlyRecurringFee": ".247",
+        "id": 209391,
+        "recurringFee": "164",
+        "categories": [
+            {
+                "categoryCode": "ram",
+                "id": 3,
+                "name": "RAM"
+            }
+        ],
+        "item": {
+            "capacity": "32",
+            "description": "32 GB RAM",
+            "id": 11291,
+            "keyName": "RAM_32_GB_DDR4_2133_ECC_NON_REG"
+        }
+    },
+    {
+        "hourlyRecurringFee": ".068",
+        "id": 22482,
+        "recurringFee": "50",
+        "categories": [
+            {
+                "categoryCode": "disk_controller",
+                "id": 11,
+                "name": "Disk Controller",
+            }
+        ],
+        "item": {
+            "capacity": "0",
+            "description": "RAID",
+            "id": 4478,
+            "keyName": "DISK_CONTROLLER_RAID",
+        }
+    },
+    {
+        "id": 50357,
+        "recurringFee": "0",
+        "categories": [
+            {
+                "categoryCode": "bandwidth",
+                "id": 10,
+                "name": "Public Bandwidth",
+            }
+        ],
+        "item": {
+            "capacity": "500",
+            "description": "500 GB Bandwidth Allotment",
+            "id": 6177,
+            "keyName": "BANDWIDTH_500_GB"
+        }
+    },
+    {
+        "hourlyRecurringFee": ".023",
+        "id": 49759,
+        "recurringFee": "15",
+        "categories": [
+            {
+                "categoryCode": "disk2",
+                "id": 6,
+                "name": "Third Hard Drive"
+            }
+        ],
+        "item": {
+            "capacity": "1000",
+            "description": "1.00 TB SATA",
+            "id": 6159,
+            "keyName": "HARD_DRIVE_1_00_TB_SATA_2",
+        }
+    },
+    {
+        "id": 49759,
+        "recurringFee": "0",
+        "categories": [
+            {
+                "categoryCode": "disk1",
+                "id": 5,
+                "name": "Second Hard Drive"
+            }
+        ],
+        "item": {
+            "capacity": "1000",
+            "description": "1.00 TB SATA",
+            "id": 6159,
+            "keyName": "HARD_DRIVE_1_00_TB_SATA_2"
+        }
+    }
+]
+
+getComponents = [{
+    "hardwareComponentModelId": 147,
+    "hardwareId": 1234,
+    "id": 369,
+    "modifyDate": "2017-11-10T16:59:38-06:00",
+    "serviceProviderId": 1,
+    "hardwareComponentModel": {
+        "name": "IMM2 - Onboard",
+        "firmwares": [
+            {
+                "createDate": "2020-09-24T13:46:29-06:00",
+                "version": "5.60"
+            },
+            {
+                "createDate": "2019-10-14T16:51:12-06:00",
+                "version": "5.10"
+            }]}}]
