@@ -43,3 +43,5 @@ getObject = {
 
 editNote = True
 setTags = True
+cancel = True
+route = True
