@@ -1847,7 +1847,16 @@ getActivePresets = [
         "isActive": "1",
         "keyName": "M1_64X512X25",
         "name": "M1.64x512x25",
-        "packageId": 835
+        "packageId": 835,
+        "locations": [],
+        "prices": [
+            {
+                "hourlyRecurringFee": "0",
+                "id": 258963,
+                "itemId": 8195,
+                "recurringFee": "0",
+                "setupFee": "0"
+            }]
     },
     {
         "description": "M1.56x448x100",
@@ -1855,7 +1864,16 @@ getActivePresets = [
         "isActive": "1",
         "keyName": "M1_56X448X100",
         "name": "M1.56x448x100",
-        "packageId": 835
+        "packageId": 835,
+        "locations": [],
+        "prices": [
+            {
+                "hourlyRecurringFee": "0",
+                "id": 698563,
+                "itemId": 8195,
+                "recurringFee": "0",
+                "setupFee": "0"
+            }]
     },
     {
         "description": "M1.64x512x100",
@@ -1863,7 +1881,16 @@ getActivePresets = [
         "isActive": "1",
         "keyName": "M1_64X512X100",
         "name": "M1.64x512x100",
-        "packageId": 835
+        "packageId": 835,
+        "locations": [],
+        "prices": [
+            {
+                "hourlyRecurringFee": "0",
+                "id": 963258,
+                "itemId": 8195,
+                "recurringFee": "0",
+                "setupFee": "0"
+            }]
     }
 ]
 
@@ -2055,3 +2082,92 @@ getObject = {
             "categoryCode": "dedicated_virtual_hosts"
         }
     }]}
+
+getItems_vmware = [{
+    "capacity": "2",
+    "description": "VMware vSAN Enterprise Tier III 65 - 124 TB 6.x",
+    "id": 9567,
+    "itemTaxCategoryId": 166,
+    "keyName": "VMWARE_VSAN_ENTERPRISE_TIER_III_65_124_TB_6_X_2",
+    "softwareDescriptionId": 1979,
+    "units": "CPU",
+    "itemCategory": {
+        "categoryCode": "software_license",
+        "id": 438,
+        "name": "Software License",
+        "quantityLimit": 1,
+    },
+    "prices": [
+        {
+            "id": 245164,
+            "itemId": 9567,
+            "laborFee": "0",
+            "locationGroupId": None,
+            "recurringFee": "0",
+            "setupFee": "0",
+            "sort": 0,
+        }
+    ]}]
+
+getItemsVLAN = [{
+    "description": "Private Network Vlan",
+    "id": 1072,
+    "itemTaxCategoryId": 166,
+    "keyName": "PRIVATE_NETWORK_VLAN",
+    "itemCategory": {
+        "categoryCode": "network_vlan",
+        "id": 113,
+        "name": "Network Vlan"},
+    "prices": [{
+        "id": 203707,
+        "itemId": 1072,
+        "laborFee": "0",
+        "locationGroupId": 505,
+        "oneTimeFee": "0",
+        "recurringFee": "0",
+        "setupFee": "0",
+        "sort": 10,
+    },
+        {
+            "id": 203727,
+            "itemId": 1072,
+            "laborFee": "0",
+            "locationGroupId": 545,
+            "oneTimeFee": "0",
+            "recurringFee": "0",
+            "setupFee": "0",
+            "sort": 10,
+    }]
+}, {
+    "description": "Public Network Vlan",
+    "id": 1071,
+    "itemTaxCategoryId": 166,
+    "keyName": "PUBLIC_NETWORK_VLAN",
+    "units": "N/A",
+    "itemCategory": {
+        "categoryCode": "network_vlan",
+        "id": 113,
+        "name": "Network Vlan",
+    },
+    "prices": [{
+        "id": 203637,
+        "itemId": 1071,
+        "laborFee": "0",
+        "locationGroupId": 509,
+        "oneTimeFee": "0",
+        "recurringFee": "0",
+        "setupFee": "0",
+        "sort": 10,
+    },
+        {
+            "id": 203667,
+            "itemId": 1071,
+            "laborFee": "0",
+            "locationGroupId": 545,
+            "oneTimeFee": "0",
+            "recurringFee": "0",
+            "setupFee": "0",
+            "sort": 10,
+    }]
+}
+]
