@@ -20,7 +20,7 @@ from SoftLayer import utils
 LOGGER = logging.getLogger(__name__)
 
 # Invalid names are ignored due to long method names and short argument names
-# pylint: disable=invalid-name, no-self-use, too-many-lines
+# pylint: disable=invalid-name, too-many-lines
 
 EXTRA_CATEGORIES = ['pri_ipv6_addresses',
                     'static_ipv6_addresses',
@@ -231,6 +231,7 @@ class HardwareManager(utils.IdentifierMixin, object):
                 'domain,'
                 'provisionDate,'
                 'hardwareStatus,'
+                'bareMetalInstanceFlag,'
                 'processorPhysicalCoreAmount,'
                 'memoryCapacity,'
                 'notes,'
@@ -269,6 +270,7 @@ class HardwareManager(utils.IdentifierMixin, object):
                 'hourlyBillingFlag,'
                 'tagReferences[id,tag[name,id]],'
                 'networkVlans[id,vlanNumber,networkSpace],'
+                'monitoringServiceComponent,networkMonitors[queryType,lastResult,responseAction],'
                 'remoteManagementAccounts[username,password]'
             )
 
@@ -1098,6 +1100,10 @@ class HardwareManager(utils.IdentifierMixin, object):
         return self.client.call('Hardware_Server', 'getComponents',
                                 mask=mask, filter=filter_component, id=hardware_id)
 
+    def get_sensors(self, hardware_id):
+        """Returns Hardware sensor data"""
+        return self.client.call('Hardware', 'getSensorData', id=hardware_id)
+
 
 def _get_bandwidth_key(items, hourly=True, no_public=False, location=None):
     """Picks a valid Bandwidth Item, returns the KeyName"""
