@@ -40,11 +40,13 @@ DEFAULT_VLAN_MASK = ','.join([
     'hardwareCount',
     'primaryRouter[id, fullyQualifiedDomainName, datacenter]',
     'subnetCount',
+    'billingItem',
     'totalPrimaryIpAddressCount',
     'virtualGuestCount',
     'networkSpace',
     'networkVlanFirewall[id,fullyQualifiedDomainName,primaryIpAddress]',
     'attachedNetworkGateway[id,name,networkFirewall]',
+    'tagReferences[tag[name]]',
 ])
 DEFAULT_GET_VLAN_MASK = ','.join([
     'firewallInterfaces',
@@ -506,7 +508,7 @@ class NetworkManager(object):
         kwargs['iter'] = True
         return self.client.call('Account', 'getSubnets', **kwargs)
 
-    def list_vlans(self, datacenter=None, vlan_number=None, name=None, **kwargs):
+    def list_vlans(self, datacenter=None, vlan_number=None, name=None, limit=100, **kwargs):
         """Display a list of all VLANs on the account.
 
         This provides a quick overview of all VLANs including information about
@@ -523,6 +525,8 @@ class NetworkManager(object):
         """
         _filter = utils.NestedDict(kwargs.get('filter') or {})
 
+        _filter['networkVlans']['id'] = utils.query_filter_orderby()
+
         if vlan_number:
             _filter['networkVlans']['vlanNumber'] = (
                 utils.query_filter(vlan_number))
@@ -540,7 +544,10 @@ class NetworkManager(object):
             kwargs['mask'] = DEFAULT_VLAN_MASK
 
         kwargs['iter'] = True
-        return self.account.getNetworkVlans(**kwargs)
+        if limit > 0:
+            return self.account.getNetworkVlans(mask=kwargs['mask'], filter=_filter.to_dict(), limit=limit)
+        else:
+            return self.account.getNetworkVlans(mask=kwargs['mask'], filter=_filter.to_dict(), iter=True)
 
     def list_securitygroups(self, **kwargs):
         """List security groups."""
@@ -785,6 +792,7 @@ class NetworkManager(object):
         returns list of all network pods and their routers.
         """
         _filter = None
+
         if datacenter:
             _filter = {"datacenterName": {"operation": datacenter}}
 
@@ -803,3 +811,43 @@ class NetworkManager(object):
         returns all routers locations.
         """
         return self.client.call('SoftLayer_Location_Datacenter', 'getHardwareRouters', id=identifier)
+
+    def get_closed_pods(self):
+        """Calls SoftLayer_Network_Pod::getAllObjects()
+
+        returns list of all closing network pods.
+        """
+        closing_filter = {
+            'capabilities': {
+                'operation': 'in',
+                'options': [{'name': 'data', 'value': ['CLOSURE_ANNOUNCED']}]
+            },
+            'name': {
+                'operation': 'orderBy',
+                'options': [{'name': 'sort', 'value': ['DESC']}]
+            }
+        }
+
+        mask = """mask[name, datacenterLongName, frontendRouterId, capabilities, datacenterId, backendRouterId,
+                backendRouterName, frontendRouterName]"""
+        return self.client.call('SoftLayer_Network_Pod', 'getAllObjects', mask=mask, filter=closing_filter)
+
+    def route(self, subnet_id, type_serv, target):
+        """Assigns a subnet to a specified target.
+
+        :param int subnet_id: The ID of the global IP being assigned
+        :param string type_serv: The type service to assign
+        :param string target: The instance to assign
+        """
+        return self.client.call('SoftLayer_Network_Subnet', 'route',
+                                type_serv, target, id=subnet_id, )
+
+    def get_datacenter(self, _filter=None, datacenter=None):
+        """Calls SoftLayer_Location::getDatacenters()
+
+        returns datacenter list.
+        """
+        if datacenter:
+            _filter = {"name": {"operation": datacenter}}
+
+        return self.client.call('SoftLayer_Location', 'getDatacenters', filter=_filter, limit=1)
