@@ -28,7 +28,7 @@ EXTRA_CATEGORIES = ['pri_ipv6_addresses',
                     'software_guard_extensions']
 
 
-# pylint: disable=no-self-use,too-many-lines
+# pylint: disable=,too-many-lines
 
 
 class VSManager(utils.IdentifierMixin, object):
@@ -227,7 +227,7 @@ class VSManager(utils.IdentifierMixin, object):
                 'maxMemory,'
                 'datacenter,'
                 'activeTransaction[id, transactionStatus[friendlyName,name]],'
-                'lastTransaction[transactionStatus],'
+                'lastTransaction[transactionStatus,modifyDate,transactionGroup[name]],'
                 'lastOperatingSystemReload.id,'
                 'blockDevices,'
                 'blockDeviceTemplateGroup[id, name, globalIdentifier],'
@@ -245,13 +245,14 @@ class VSManager(utils.IdentifierMixin, object):
                 'userData,'
                 '''billingItem[id,nextInvoiceTotalRecurringAmount,
                                package[id,keyName],
-                               children[categoryCode,nextInvoiceTotalRecurringAmount],
+                               children[description,categoryCode,nextInvoiceTotalRecurringAmount],
                                orderItem[id,
                                          order.userRecord[username],
                                          preset.keyName]],'''
                 'tagReferences[id,tag[name,id]],'
                 'networkVlans[id,vlanNumber,networkSpace],'
                 'dedicatedHost.id,'
+                'monitoringServiceComponent,networkMonitors[queryType,lastResult,responseAction],'
                 'placementGroupId'
             )
 
@@ -359,7 +360,7 @@ class VSManager(utils.IdentifierMixin, object):
                     'prices': get_item_price(item['prices'], location_group_id)
                 })
 
-            elif category.__contains__('guest_disk'):
+            elif 'guest_disk' in category:
                 local_disk.append({
                     'name': item['description'],
                     'capacity': item['capacity'],
@@ -1042,7 +1043,7 @@ class VSManager(utils.IdentifierMixin, object):
             disk_number = 0
             vsi_disk = self.get_instance(instance_id)
             for item in vsi_disk.get('billingItem').get('children'):
-                if item.get('categoryCode').__contains__('guest_disk'):
+                if 'guest_disk' in item.get('categoryCode'):
                     if disk_number < int("".join(filter(str.isdigit, item.get('categoryCode')))):
                         disk_number = int("".join(filter(str.isdigit, item.get('categoryCode'))))
             for disk_guest in disk:
@@ -1066,8 +1067,8 @@ class VSManager(utils.IdentifierMixin, object):
                 category = {'categories': [{
                     'categoryCode': 'guest_disk' + str(disk_number),
                     'complexType': "SoftLayer_Product_Item_Category"}],
-                            'complexType': 'SoftLayer_Product_Item_Price',
-                            'id': price_id}
+                    'complexType': 'SoftLayer_Product_Item_Price',
+                    'id': price_id}
 
                 prices.append(category)
             order['prices'] = prices
@@ -1404,3 +1405,45 @@ class VSManager(utils.IdentifierMixin, object):
         object_filter = {"hardware": {"virtualHost": {"id": {"operation": "not null"}}}}
         mask = "mask[virtualHost[guests[powerState]]]"
         return self.client.call('SoftLayer_Account', 'getHardware', mask=mask, filter=object_filter)
+
+    def authorize_storage(self, vs_id, username_storage):
+        """Authorize File or Block Storage to a Virtual Server.
+
+        :param int vs_id: Virtual server id.
+        :param string username_storage: Storage username.
+
+        :return: bool.
+        """
+        _filter = {"networkStorage": {"username": {"operation": username_storage}}}
+
+        storage_result = self.client.call('Account', 'getNetworkStorage', filter=_filter)
+
+        if len(storage_result) == 0:
+            raise SoftLayerError("The Storage with username: %s was not found, please"
+                                 " enter a valid storage username" % username_storage)
+
+        storage_template = [
+            {
+                "id": storage_result[0]['id'],
+                "username": username_storage
+            }
+        ]
+
+        result = self.client.call('SoftLayer_Virtual_Guest', 'allowAccessToNetworkStorageList',
+                                  storage_template, id=vs_id)
+
+        return result
+
+    def attach_portable_storage(self, vs_id, portable_id):
+        """Attach portal storage to a Virtual Server.
+
+        :param int vs_id: Virtual server id.
+        :param int portable_id: Portal storage id.
+
+        :return: SoftLayer_Provisioning_Version1_Transaction.
+        """
+        disk_id = portable_id
+        result = self.client.call('SoftLayer_Virtual_Guest', 'attachDiskImage',
+                                  disk_id, id=vs_id)
+
+        return result
